==> biocDatasets_1.0.0.tar.gz: biocDatasets/man/tilingProbes.Rd <==
\name{tilingProbes}
\alias{tilingProbes}
\alias{tilingIRanges}
\title{ Create tiling probes or ranges }
\description{
  Create tiling probes or ranges
}
\usage{

tilingProbes(width, step, template_seq)

tilingIRanges(width, step, from, to)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{from}{ start position for the tiling}
  \item{step}{ increment in the starting index between one probe
    and the next. }
  \item{template_seq}{ template sequence from which tiling probes are
    to be extracted }
  \item{to}{ end position for the tiling }
  \item{width}{ width for the probes }
}
%\details{
%  ~~ If necessary, more details than the description above ~~
%}
\value{
  \code{tilingProbes} and \code{tilingIRanges} return
  a \code{\link[Biostrings]{DNAStringSet}}
  and a \code{\link[Biostrings]{IRanges}} respectively.
}
%\references{ ~put references to the literature/web site here ~ }
%\author{ ~~who you are~~ }
%\note{ ~~further notes~~ 
%
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{

dna <- randomDNASequences(1, 30)[[1]]

tip <- tilingProbes(10, 2, dna)

# ASCII-art
cat(as.character(dna), "\n")
for (i in 1:length(tip)) {
  cat(paste(rep("|", (i-1)*2), collapse=""),
      as.character(tip[[i]]), "\n",
      sep="")
}
cat(as.character(dna), "\n")

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }

==> biocDatasets_1.2.0.tar.gz: biocDatasets/man/tilingProbes.Rd <==
\name{tilingProbes}
\alias{tilingProbes}
\alias{tilingIRanges}
\title{ Create tiling probes or ranges }
\description{
  Create tiling probes or ranges
}
\usage{

tilingProbes(width, step, template_seq)

tilingIRanges(width, step, from, to)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{from}{ start position for the tiling}
  \item{step}{ increment in the starting index between one probe
    and the next. }
  \item{template_seq}{ template sequence from which tiling probes are
    to be extracted }
  \item{to}{ end position for the tiling }
  \item{width}{ width for the probes }
}
%\details{
%  ~~ If necessary, more details than the description above ~~
%}
\value{
  \code{tilingProbes} and \code{tilingIRanges} return
  a \code{\link[Biostrings:XStringSet-class]{DNAStringSet}}
  and a \code{\link[IRanges:IRanges-class]{IRanges}} respectively.
}
%\references{ ~put references to the literature/web site here ~ }
%\author{ ~~who you are~~ }
%\note{ ~~further notes~~ 
%
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{

dna <- randomDNASequences(1, 30)[[1]]

tip <- tilingProbes(10, 2, dna)

# ASCII-art
cat(as.character(dna), "\n")
for (i in 1:length(tip)) {
  cat(paste(rep("|", (i-1)*2), collapse=""),
      as.character(tip[[i]]), "\n",
      sep="")
}
cat(as.character(dna), "\n")

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
